@@ -336,6 +336,10 @@ def pytest_addoption(parser):
                          dest="case",
                          default="-1",
                          help="Number of case which need to run in Excel config. Do no use this option for running all cases. Input number > 0")
+        parser.addoption("--caseid",
+                         dest="caseid",
+                         default='',
+                         help="Case ID which need to run in Excel config. Do no use this option for running all cases. Only support 1 case")
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
