@@ -1072,6 +1072,16 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("An exception occured when scrolling down")
             return None
 
+    def scroll_up(self, locator, wait_time=0.5):
+        "Scroll down"
+        try:
+            element = self.get_element(locator)
+            element.send_keys(Keys.PAGE_UP)
+            self.wait(wait_time)
+        except Exception as e:
+            self.write(str(e), 'debug')
+            self.exceptions.append("An exception occured when scrolling up")
+            return None
     def key_press_END(self, locator, wait_time=0.5):
         "Scroll down"
         try:
